---
title: "Create your site file"
description: "Instructions for initializing a site using the `render-engine init` CLI command, including installation of `cookiecutter` and customization options."
date: August 22, 2024
tags: ["initialization", "cli", "cookiecutter", "render-engine"]
---

You can get started quickly using the `render-engine init` cli command.

Then run the init command and provide the required parameters for initializing a template.

```bash
render-engine init
```

or

```bash
python -m render_engine init
```

## Available Options

`init` has a few options that you can use to customize your site

You can view the options using the `--help` flag.
![render-engine init --help]

Visit the [CLI - init] page for more information.

### Continue to [Simple Site Layout]

[cli - init]: ../cli.md
[render-engine init --help]: ../assets/render-engine-init-help.png
[simple site layout]: layout.md
